# if you want to build glibc on this build platform for target ppc, building
# for ppc:
#rpmbuild -ba -target ppc-openmamba-linux-gnu glibc.spec

# example: build a ppc cross-platform glibc package:
#rpmbuild -ba --define='cross_target_cpu ppc' glibc.spec

# example: build a arm cross-platform glibc package with soft floating point support:
#rpmbuild -ba --define='cross_target_cpu arm' --define='softfloat 1' glibc.spec

%define majver %(echo %version | cut -d. -f1-2)

#% if "%{?KERNEL_VER}" == ""
#   % define KERNEL_VER             %(uname -r | sed "s|\\([0-9.]*\\).*|\\1|" )
#% endif

%if "%{?KERNEL_TARGET}" == ""
%ifarch %{ix86}
%define KERNEL_TARGET mamba
%else
%define KERNEL_TARGET mamba-%{_target_cpu}
%endif
%endif

%if "%{?build_doc}" == ""
%define build_doc      1
%endif

%if "%{?build_selinux}" == ""
%define build_selinux  1
%endif

# build a soft floating point targeted library (currently only for ARM)
%if "%{?bigendian}"
%define bigendian_append -bigendian
%endif

# build a soft floating point targeted library (currently only for ARM)
%if "%{?softfloat}"
%define softfloat_append -softfloat
%endif

# stage1: build only headers package
%if "%{stage1}" == "1"
%define bootstrap_append -stage1
%define build_doc      0
%define build_selinux  0
%endif

# stage2: build what you can without requirements may not be present yet (doc,profile,selinux)
%if "%{stage2}" == "1"
%define bootstrap_append -stage2
%define build_doc      0
%define build_selinux  0
%endif

%define target_cpu %(echo %{_target_platform} | cut -d- -f1)

%if "%{_target_platform}" != "%{_host}"
   %define _as %{_target_platform}-as
   %define _ld %{_target_platform}-ld
   %define glibc_prefix %{_prefix}/%{_target_platform}
   %define glibc_libdir %{_prefix}/%{_target_platform}/lib
   %define glibc_datadir %{_prefix}/%{_target_platform}/share
   %define glibc_libexecdir %{_prefix}/%{_target_platform}/libexec
   %define glibc_includedir %{_prefix}/%{_target_platform}/include
   %define glibc_target_cpu %{_target_cpu}
   %define slibdir %{_prefix}/%{_target_platform}/lib
%else
   %define _as as
   %define _ld ld
   %define glibc_prefix %{_prefix}
   %define glibc_libdir %{_libdir}
   %define glibc_datadir %{_datadir}
   %define glibc_libexecdir %{_libexecdir}
   %define glibc_includedir %{_includedir}
   %define glibc_target_cpu %{_target_cpu}
   %define slibdir %{_libdir}
%endif
%define buildcc %{_target_platform}-gcc
%define buildcxx %{_target_platform}-g++

%if "%{_target_platform}" != "%{_build}"
%define build_doc 0
%define build_selinux 0
%endif

Name:          glibc
Version:       2.41
Release:       1mamba
Summary:       The GNU libc libraries
Group:         System/Libraries
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://www.gnu.org/software/libc/
Source0:       https://ftp.gnu.org/gnu/glibc/glibc-%{version}.tar.xz
Source4:       nscd-logrotate
Source5:       nscd-conf
Source6:       nscd-initscript
Source7:       glibc-locale-gen
Source8:       glibc-locale.gen.txt
Patch5:        glibc-2.16.0-localedata_openmamba.patch
Patch17:       glibc-2.21-prevent-ehaustion-of-tls-slots.patch
License:       LGPL
## AUTOBUILDREQ-BEGIN
## AUTOBUILDREQ-END
BuildRequires: libidn-devel
BuildRequires: binutils >= 2.13
%if "%{_host}" == "%{_build}"
BuildRequires: coreutils >= 5.2.1
BuildRequires: perl >= 5.8.0
%endif
BuildRequires: gettext-devel >= 0.14.0
BuildRequires: gawk
BuildRequires: bison
BuildRequires: texinfo >= 4.8
%if "%{?build_doc}" != "0"
BuildRequires: tetex
BuildRequires: tetex-latex
Requires(post):%{__install_info}
%endif
%if "%{?build_selinux}" != "0"
BuildRequires: libselinux-devel >= 1.22
BuildRequires: libcap-devel
%endif
%if "%{?stage1}" != "1"
BuildRequires: kernelsanitisedheaders
BuildRequires: libpython3-devel
BuildRequires: elfutils
%endif
Requires:      ldconfig = %{?epoch:%epoch:}%{version}-%{release}
Requires:      glibc-common = %{?epoch:%epoch:}%{version}-%{release}
Requires:      glibc-utils = %{?epoch:%epoch:}%{version}-%{release}
Requires(pre): libxcrypt
%systemd_requires

%description
The glibc package contains standard libraries which are used by multiple programs on the system.
In order to save disk space and memory, as well as to make upgrading easier, common system code is kept in one place and shared between programs.
This particular package contains the most important sets of shared libraries: the standard C library and the standard math library. Without these two libraries, a Linux system will not function.
The glibc package also contains national language (locale) support.

%package devel
Summary:       Header and object files for development using standard C libraries.
Group:         Development/Libraries
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}
Requires(pre): %{__install_info}
Requires:      libxcrypt-devel

%description devel
The glibc-devel package contains the header and object files necessary for developing programs which use the standard C libraries (which are used by nearly all programs).
If you are developing programs which will use the standard C libraries, your system needs to have these standard header and object files available in order to create the executables.

This package also includes the C header files for the Linux kernel.
The header files define structures and constants that are needed for building most standard programs.
The header files are also needed for rebuilding the kernel.

Install glibc-devel if you are going to develop programs which will use the standard C libraries.

%package multilib
Summary:        GNU libc multilib (lib32) libraries
Group:          System/Libraries
Provides:       glibc-multilib-i18ndata
Obsoletes:      glibc-multilib-i18ndata < 2.34
Provides:       glibc-multilib-utils
Obsoletes:      glibc-multilib-utils < 2.34

%description multilib
The glibc package contains standard libraries which are used by multiple programs on the system.
In order to save disk space and memory, as well as to make upgrading easier, common system code is kept in one place and shared between programs.
This particular package contains the most important sets of shared libraries: the standard C library and the standard math library. Without these two libraries, a Linux system will not function.
The glibc-multilib package provides lib32 libraries for 32-bit build support on x86_64 arch.

%package multilib-devel
Summary:        GNU libc multilib (lib32) libraries and files for development
Group:          Development/Libraries
Requires:       glibc-multilib =  %{?epoch:%epoch:}%{version}-%{release}
Provides:       glibc-multilib-apidocs
Obsoletes:      glibc-multilib-apidocs < 2.34

%description multilib-devel
The glibc package contains standard libraries which are used by multiple programs on the system.
In order to save disk space and memory, as well as to make upgrading easier, common system code is kept in one place and shared between programs.
This particular package contains the most important sets of shared libraries: the standard C library and the standard math library. Without these two libraries, a Linux system will not function.
The glibc-multilib-devel package provides lib32 libbraries and other files for development for 32-bit build support on x86_64 arch.

%if %{build_doc}
%package apidocs
Summary:        GNU libc libraries API documentation
Group:          Documentation
Requires:       glibc-devel =  %{?epoch:%epoch:}%{version}-%{release}

%description apidocs
GNU libc libraries API documentation.
%endif

%package common
Summary:       Common files shared by multiple binary glibc installations
Group:         System/Libraries
Provides:      glibc-i18ndata
Obsoletes:     glibc-i18ndata <= 2.40-2mamba
Provides:      locales
Obsoletes:     locales <= 2.40-2mamba

%description common
Common files shared by multiple binary glibc installations.

%package locales
Summary:       Pregenerated locales for the GNU C Library
Group:         System/Internationalization

%description locales
Pregenerated locales for the GNU C Library.

%package utils
Summary:       Development utilities from GNU C library
Group:         Development/Tools
Requires(post): gawk
Requires(post): grep
Requires(post): sed
Requires(post): %{name} = %{?epoch:%epoch:}%{version}-%{release}
Requires(post): glibc-common = %{?epoch:%epoch:}%{version}-%{release}

%description utils
The glibc-utils package contains memusage, a memory usage profiler, mtrace, a memory leak tracer and, a function call tracer which can be helpful during program debugging.

%package -n ldconfig
Summary:       Configure dynamic linker run time bindings
Group:         System/Tools
# The dynamic linker supports DT_GNU_HASH
Provides:      rtld(GNU_HASH)
Provides:      rtld(GNU_UNIQUE)
Provides:      /sbin/ldconfig

%description -n ldconfig
ldconfig creates the necessary links and cache to the most recent shared libraries found in the directories specified on the command line, in the file /etc/ld.so.conf, and in the trusted directories (/lib and /usr/lib).
The cache is used by the run-time linker, ld.so or ld-linux.so.
ldconfig checks the header and file names of the libraries it encounters when determining which versions should have their links updated.

%package -n timezone
Summary:       Time zone descriptions
Group:         System/Internationalization
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}
Requires(post):tzdata

%description -n timezone
These are configuration files that describe possible time zones.

%package -n nscd
Summary:       Name service cache daemon
Group:         System/Servers
Requires:      logrotate >= 3.6.8
Provides:      user(nscd)
Provides:      group(nscd)

%description -n nscd
Nscd is a daemon that provides a cache for the most common name service requests.

%package -n cross-%{_target_platform}-%{name}%{?bootstrap_append}%{?bigendian_append}%{?softfloat_append}
Summary:       Cross Platform glibc for %{_target_platform}
Group:         System/Libraries
AutoReqProv:   no
%if "%{?stage2}"
Obsoletes: cross-%{_target_platform}-%{name}-stage1%{?bigendian_append}%{?softfloat_append} <= %{version}-%{release}
%else
%if "%{?stage1}" == ""
Provides:  cross-%{_target_platform}-%{name}-stage2%{?bigendian_append}%{?softfloat_append}
Obsoletes: cross-%{_target_platform}-%{name}-stage2%{?bigendian_append}%{?softfloat_append} <= %{version}-%{release}
Obsoletes: cross-%{_target_platform}-%{name}-stage1%{?bigendian_append}%{?softfloat_append} <= %{version}-%{release}
%endif
%endif

%description -n cross-%{_target_platform}-%{name}%{?bootstrap_append}%{?bigendian_append}%{?softfloat_append}
Cross Platform glibc for %{_target_platform}.

%if "%{_target_platform}" == "%{_host}"
%endif

# Don't clean build at the end
%global __spec_rmbuild_cmd /bin/true

# Filter out all GLIBC_PRIVATE symbols since they are internal to
# the package and should not be examined by any other tool.
%global __filter_GLIBC_PRIVATE 1

%prep
%setup -q
#-D -T
#:<< ___EOF
%patch 17 -p1

%if "%{?stage2}"
   # link glibc without libgcc_eh, not available in stage1 cross compiler
   # this is the reason why also a glibc rebuild is needed later
   sed -i "s|-lgcc_eh||" Makeconfig
%endif

%if %{build_selinux}
ln -sf %{_includedir}/selinux selinux
ln -sf %{_includedir}/sys/capability.h include/sys/capability.h
%endif

%build
#:<< ___EOF
case %{target_cpu} in
   i*86|athlon*)
     platform_includes=asm-x86
     buildflags="-mtune=pentiumpro -g -O2"
     CONFIG_OPTS="--enable-targets=i586-%{_target_vendor}-linux --enable-static-pie"
   ;;
   ppc|powerpc)
     platform_includes=asm-powerpc
     buildflags="-g -O2"
     CONFIG_OPTS="--enable-targets=powerpc64-%{_target_vendor}-linux"
   ;;
   arm)
     platform_includes=asm-arm
     buildflags="-g -O2"
     %if "%{?softfloat}" == "1"
       CONFIG_LIBDIR_ADD="/soft-float"
       CONFIG_ADD="--without-fp"
       CC_ADD="-msoft-float"
     %endif
     %if "%{?bigendian}" == "1"
       CONFIG_LIBDIR_ADD="/be${CONFIG_LIBDIR_ADD}"
       CC_ADD="-mbig-endian"
       AS_ADD="-mbig-endian"
     %endif
     CONFIG_OPTS=""
     ;;
   x86_64)
     platform_includes=asm-x86_64
     buildflags="-g -O2"
     CONFIG_OPTS="--enable-targets=x86_64-%{_target_vendor}-linux --enable-multi-arch --enable-static-pie --enable-cet"
     ;;
   aarch64)
     platform_includes=asm-aarch64
     buildflags="-g -O2"
     CONFIG_OPTS="--enable-targets=aarch64-%{_target_vendor}-linux --enable-multi-arch --enable-static-pie --enable-cet"
     ;;
   *)
     echo "Target CPU %{target_cpu} not supported. Aborting."
     exit 1
   ;;
esac


# set kernel headers for platform
if  [ -e /usr/src/linux-%{KERNEL_VERSION}%{KERNEL_TARGET}/usr/include/linux/version.h ]; then
   headers_dir=/usr/src/linux-%{KERNEL_VERSION}%{KERNEL_TARGET}/usr/include
elif [ -e /usr/src/linux-%{KERNEL_TARGET}/usr/include/linux/version.h ]; then
   headers_dir=/usr/src/linux-%{KERNEL_TARGET}/usr/include
elif [ -e /usr/src/linux/usr/include/linux/version.h ]; then
   headers_dir=/usr/src/linux/usr/include
else
   echo "ERROR: can't find suitable kernel headers; aborting."
   exit 1
fi

%if "%{?stage2}"
# hack, diable nptl for bootstrap gcc
opt_tls="--enable-add-ons --with-tls --disable-sanity-checks"
%else
opt_tls="--enable-add-ons --with-tls"
%endif

%if %{build_selinux}
opt_selinux="--with-selinux"
%else
opt_selinux="--without-selinux"
%endif

%if "%{?stage2}" == "1"
  # there is no --disable-ssp option
  echo "libc_cv_ssp=no" > config.cache
%endif

_configure_flags=(
   --build=%{_build} \
%if "%{?stage1}" != "1"
   --host=%{_target_platform} \
%endif
%if "%{?stage2}"
   --cache-file=config.cache \
%endif
   --prefix=%{glibc_prefix} \
   --infodir=%{_infodir} \
   --libexecdir=%{glibc_libexecdir} \
#   --with-headers=${headers_dir} \
   --with-bugurl=https://bugs.openmamba.org/ \
   ${opt_tls} ${opt_selinux} \
   --enable-lock-elision \
%if "%{_target_platform}" == "%{_host}"
   --enable-stack-protector=strong \
   --enable-stackguard-randomization \
   --enable-systemtap \
%endif
   --enable-bind-now \
   --enable-lock-elision \
   --disable-profile \
   --disable-werror \
   PYTHON_PROG=%{__python3} \
   $CONFIG_OPTS
)

#:<< __EOF
# Build
rm -rf ../glibc-build-%{_target_platform}
mkdir ../glibc-build-%{_target_platform}
cd ../glibc-build-%{_target_platform}

export CFLAGS="$buildflags"
export CXXFLAGS="$buildflags"

../%{name}-%{version}/configure \
   ${_configure_flags[@]}

echo "slibdir=%{slibdir}" >> configparms
%if "%{_target_platform}" == "%{_host}"
echo "rtlddir=%{_libdir}" >> configparms
echo "sbindir=%{_bindir}" >> configparms
echo "rootsbindir=%{_sbindir}" >> configparms
%endif

%if "%{?stage1}" != "1"
# build libraries with fortify disabled
echo "build-programs=no" >> configparms

make %{_smp_mflags} -r %PARALLELMFLAGS=-s -j1 slibdir=%{slibdir} \
%if "%{_target_platform}" != "%{_host}"
%if "%{?stage2}" != "1"
  LDLIBS-resolv.so+="-lssp" LDFLAGS-nscd+="-lssp"
%else
  CXX=
%endif
%endif

# re-enable fortify for programs
sed -i "/build-programs=/s#no#yes#" configparms
echo "CC += -D_FORTIFY_SOURCE=2" >> configparms
echo "CXX += -D_FORTIFY_SOURCE=2" >> configparms
make %{_smp_mflags} -r %PARALLELMFLAGS=-s slibdir=%{slibdir}

#:<< __EOF
# build documentation (pdf and html formats)
%if %{build_doc}
make pdf html
%endif

%endif

#__EOF

%if "%{_target_platform}" == "%{_host}"
%ifarch x86_64
%if "%{?stage1}" != "1"
%if "%{?stage2}" != "1"
# Multilib
rm -rf ../glibc-multilib-build-%{_target_platform}
mkdir ../glibc-multilib-build-%{_target_platform}
cd ../glibc-multilib-build-%{_target_platform}

export CC="gcc -m32 -mstackrealign"
export CXX="g++ -m32 -mstackrealign"

CFLAGS="-mtune=pentiumpro -g -O3 -Wl,--build-id"

../%{name}-%{version}/configure \
   ${_configure_flags[@]} \
   --host=i586-openmamba-linux-gnu \
   --libdir=/usr/lib32 \
   --libexecdir=/usr/lib32 \
   --disable-cet \
   --without-selinux

# Disable building programs
echo "build-programs=no" >> configparms
echo "slibdir=/usr/lib32" >> configparms
echo "rtlddir=/usr/lib32" >> configparms

make %{_smp_mflags} -r %PARALLELMFLAGS=-s

%endif
%endif
%endif
%endif

%install
[ "%{buildroot}" != / ] && rm -rf %{buildroot}

%if "%{?stage1}" != "1"
# crelate ld.so.conf
install -d %{buildroot}%{_sysconfdir}/ld.so.conf.d
cat > %{buildroot}%{_sysconfdir}/ld.so.conf << _EOF
include %{_sysconfdir}/ld.so.conf.d/*.conf
_EOF

%if "%{_target_platform}" == "%{_host}"
# Multilib
%ifarch x86_64
%makeinstall -C ../glibc-multilib-build-%{_target_platform}
cat > %{buildroot}%{_sysconfdir}/ld.so.conf.d/lib32-glibc.conf << _EOF
/usr/lib32
_EOF
# Symlink /usr/lib32/locale to /usr/lib/locale
ln -s ../lib/locale %{buildroot}/usr/lib32/locale
%endif
%endif

%makeinstall -C ../glibc-build-%{_target_platform}

%if "%{_target_platform}" == "%{_build}"
%ifarch aarch64
   install -d -m0755 %{buildroot}%{_prefix}/lib
   ln -s ../lib64/ld-linux-aarch64.so.1 %{buildroot}%{_prefix}/lib/ld-linux-aarch64.so.1
%endif
   # install locale-gen
   install -D -m0755 %{SOURCE7} %{buildroot}%{_bindir}/locale-gen

   # Create /etc/locale.gen
   install -m644 %{SOURCE8} %{buildroot}%{_sysconfdir}/locale.gen
   sed -e '1,3d' -e 's|/| |g' -e 's| \\||g' -e 's|^|#|g' \
      localedata/SUPPORTED >> %{buildroot}%{_sysconfdir}/locale.gen
   sed -i '/#C\.UTF-8 /d' %{buildroot}%{_sysconfdir}/locale.gen
   make localedata/install-locale-files -C ../glibc-build-%{_target_platform} install_root=%{buildroot}

%else
   # WORKAROUND: worked up to 2.21
   mkdir -p %{buildroot}%{_prefix}/lib/locale
   make LOCALEDEF="I18NPATH=. LC_ALL=C localedef" localedata/install-locale-files -C ../glibc-build-%{_target_platform} install_root=%{buildroot}
   install -d -m0755 %{buildroot}%{glibc_prefix}/lib/locale/
   mv %{buildroot}%{_prefix}/lib/locale/* %{buildroot}%{glibc_prefix}/lib/locale/
%endif
   # Locale creation via install-locale-files does not group identical files
   # via hardlinks, so we must group them ourselves.
   hardlink -c %{buildroot}/%{glibc_prefix}/lib/locale
   # Replace LC_CTYPE same files with symlinks to consistently reduce size of glibc-locales package
   pushd %{buildroot}%{glibc_prefix}/lib/locale
      for f in $(find eo syr tok *_* -samefile C.utf8/LC_CTYPE); do
         rm $f && ln -s '../C.utf8/LC_CTYPE' $f
      done
   popd
   # Add SUPPORTED file to package
   # Note: needs to be reformatted like /etc/locale.gen e.g. for Calamares
   sed -e '1,3d' -e 's|/| |g' -e 's| \\||g' \
      localedata/SUPPORTED > %{buildroot}%{glibc_datadir}/i18n/SUPPORTED

[-e %{buildroot}%{glibc_libdir}/libbsd-compat.a ] && ln -sf libbsd-compat.a %{buildroot}%{glibc_libdir}/libbsd.a
%else
  # stage 1
   make -C ../glibc-build-%{_target_platform} install-headers install_root=%{buildroot} cross-compiling=yes
  # the following files are generated during the glibc build.
  # Fortunately, it is sufficient to substitute empty files for a first stage gcc build
  touch %{buildroot}%{glibc_includedir}/gnu/stubs.h
  touch %{buildroot}%{glibc_includedir}/bits/stdio_lim.h
%endif

rm -f %{buildroot}%{_sysconfdir}/localtime

# install kernel headers
if  [ -e /usr/src/linux-%{KERNEL_VERSION}%{KERNEL_TARGET}/usr/include/linux/version.h ]; then
   headers_dir=/usr/src/linux-%{KERNEL_VERSION}%{KERNEL_TARGET}/usr/include
elif [ -e /usr/src/linux-%{KERNEL_TARGET}/usr/include/linux/version.h ]; then
   headers_dir=/usr/src/linux-%{KERNEL_TARGET}/usr/include
elif [ -e /usr/src/linux/usr/include/linux/version.h ]; then
   headers_dir=/usr/src/linux/usr/include
else
   echo "ERROR: can't find suitable kernel headers; aborting."
   exit 1
fi

cp -avrf ${headers_dir}/* %{buildroot}%{glibc_includedir}

%if "%{_target_platform}" == "%{_host}"
# install/create nscd service dirs and configuration files
install -d %{buildroot}/var/log/nscd
install -D -m644 %{SOURCE4} %{buildroot}%{_sysconfdir}/logrotate.d/nscd
install -D -m644 %{SOURCE5} %{buildroot}%{_sysconfdir}/nscd.conf
install -D -m644 nscd/nscd.service %{buildroot}%{_unitdir}/nscd.service
install -D -m644 nscd/nscd.tmpfiles %{buildroot}%{_tmpfilesdir}/nscd.conf
# Provide pre 2.34 legacy symlinks
ln -s libdl.so.2 %{buildroot}%{glibc_libdir}/libdl.so
ln -s libpthread.so.0 %{buildroot}%{glibc_libdir}/libpthread.so
ln -s librt.so.1 %{buildroot}%{glibc_libdir}/librt.so
ln -s libutil.so.1 %{buildroot}%{glibc_libdir}/libutil.so

%else
rm -rf %{buildroot}%{_sysconfdir}
rm -rf %{buildroot}%{_infodir}
rm -rf %{buildroot}%{_mandir}
rm -f %{buildroot}%{_prefix}/%{_target_platform}/%{_sysconfdir}/localtime
rm -f %{buildroot}%{_localstatedir}/db/Makefile
rm -f %{buildroot}%{_prefix}/%{_target_platform}/%{_sysconfdir}/ld.so.cache
%endif

# work around to avoid stripping libthread_db-1.0.so for debugging
%if "%{_target_platform}" == "%{_host}"
%if "%{?stage1}" != "1"
#chmod -x %{buildroot}/%{slibdir}/ld-*.so
#chmod -x %{buildroot}/%{slibdir}/libc-*.so
chmod -w %{buildroot}/%{slibdir}/libpthread*.so.*
chmod -w %{buildroot}/%{slibdir}/libthread_db*.so.*
%endif
%endif

%if "%{_target_platform}" == "%{_host}"
## 2.26: workaround for header required by external libnss_nis
#install -D -m0644 resolv/mapv4v6addr.h %{buildroot}%{_includedir}/resolv/mapv4v6addr.h
# legacy symlink
ln -s locale.h %{buildroot}%{_includedir}/xlocale.h
%endif

%if "%{?stage1}" != "1"
## strip debug symbols
#find %{buildroot}%{glibc_libdir} -maxdepth 1 -type f \
#   -exec strip -g -R .comment {} 2>/dev/null \;
##strip -g -R .comment %{buildroot}%{_libexecdir}/pt_chown

%find_lang libc

%if "%{_target_platform}" == "%{_host}"
#install api documentation
%if %{build_doc}
install -d %{buildroot}%{_docdir}/libc/html
cp -a ../glibc-build-%{_target_platform}/manual/libc/* %{buildroot}%{_docdir}/libc/html/
cp -a ../glibc-build-%{_target_platform}/manual/libc.pdf %{buildroot}%{_docdir}/libc/
%endif
%endif

%endif

rm -f %{buildroot}%{_sysconfdir}/ld.so.cache

# updated zoneinfo provided by tzdata
rm -rf %{buildroot}%{glibc_datadir}/zoneinfo

%clean
[ "%{buildroot}" != / ] && rm -rf %{buildroot}

%post utils
if [ $1 -ge 1 ]; then
   # update locale.gen to make sure current LANG locale is enabled
   LOCALES=(`grep ${LANG/utf*/UTF-8} %{glibc_datadir}/i18n/SUPPORTED | awk '{ print $1 }'`);
   for l in ${LOCALES[*]/\/*/}; do
      sed -i "s|#${l}|${l}|" %{_sysconfdir}/locale.gen
   done
   # update locale-archive according to locale.gen
   locale-gen
fi
:

%posttrans utils
if [ $1 -ge 1 ]; then
   # Regenerated locale-archive if it has been deleted by a old glibc
   [ -e /usr/lib/locale/locale-archive ] || locale-gen
fi
:

%ifarch x86_64
%transfiletriggerin -n ldconfig -P 2000000 -- %{_libdir} %{_prefix}/lib
%else
%transfiletriggerin -n ldconfig -P 2000000 -- %{_libdir}
%endif
%{_bindir}/ldconfig
:

%ifarch x86_64
%transfiletriggerpostun -n ldconfig -P 2000000 -- %{_libdir} %{_prefix}/lib
%else
%transfiletriggerpostun -n ldconfig -P 2000000 -- %{_libdir}
%endif
%{_bindir}/ldconfig
:

%pre devel
[ -L %{_includedir}/asm ] && rm -f %{_includedir}/asm

# Remove old directory asm-<arch>
case %{target_cpu} in
   i*86 | athlon*)
      platform_includes=asm-i386
      ;;
   ppc | powerpc)
      platform_includes=asm-ppc
      ;;
   arm)
      platform_includes=asm-arm
      ;;
   *)
      platform_includes=asm-orphan
      ;;
esac

if [ "$platform_includes" -a -d %{_includedir}/$platform_includes ]; then
   rm -f %{_includedir}/$platform_includes/*
   rmdir %{_includedir}/$platform_includes
fi
:

%post devel
%install_info libc.info
:

%postun devel
%uninstall_info libc.info
:

%pre -n nscd
if [ $1 -ge 1 ]; then
   /usr/sbin/groupadd -g 65001 nscd &>/dev/null || true
   /usr/sbin/useradd -u 65001 -g nscd -d /dev/null nscd -s /bin/false &>/dev/null || true
fi
%systemd_pre nscd
:

%post -n nscd
if [ $1 -ge 1 ]; then
   %tmpfiles_create nscd.conf
fi   
%systemd_post nscd
:

%preun -n nscd
%systemd_preun nscd
if [ $1 -eq 0 ]; then
   /usr/sbin/userdel nscd
fi
:

%postun -n nscd
%systemd_postun_with_restart nscd
:

%if "%{_target_platform}" == "%{_host}"
%files
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/rpc
%attr(0755,-,-) /%{slibdir}/lib*.so.*
%ifarch aarch64
%{_prefix}/lib/ld-linux-aarch64.so.1
%endif
%attr(0755,-,-) %{_libdir}/ld-linux*.so.*
%exclude %{slibdir}/libmemusage.so
%exclude %{slibdir}/libpcprofile.so
%dir %{glibc_libdir}/gconv
%{glibc_libdir}/gconv/*
%dir %{glibc_libexecdir}/getconf
%{glibc_libexecdir}/getconf/*
%doc COPYING* LICENSES

%files devel
%defattr(-,root,root)
%{glibc_includedir}/*
%{glibc_libdir}/*.o
%{glibc_libdir}/*.so
%{glibc_libdir}/*.a
%if "%{build_profile}" == "1"
%exclude %{glibc_libdir}/lib*_p.a
%endif
%{_infodir}/*
%{_localstatedir}/db/Makefile
%doc NEWS README*

%ifarch x86_64
%files multilib
%defattr(-,root,root)
%{_sysconfdir}/ld.so.conf.d/lib32-glibc.conf
%{_prefix}/lib32/lib*.so.*
%dir %{_prefix}/lib32/audit
%{_prefix}/lib32/audit/sotruss-lib.so
%{_prefix}/lib32/ld-linux.so.*
%dir %{_prefix}/lib32/gconv
%{_prefix}/lib32/gconv/*
%{_prefix}/lib32/locale

%files multilib-devel
%defattr(-,root,root)
%{_prefix}/lib32/*.o
%{_prefix}/lib32/lib*.a
%{_prefix}/lib32/lib*.so
%endif

%if %{build_doc}
%files apidocs
%defattr(-,root,root)
%dir %{_docdir}/libc/
%{_docdir}/libc/*
%endif

%files common -f libc.lang
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/locale.gen
%dir %{_prefix}/lib/locale
%dir %{_prefix}/lib/locale/C.utf8
%{_prefix}/lib/locale/C.utf8/*
%dir %{glibc_datadir}/i18n
%{glibc_datadir}/i18n/*
%{glibc_datadir}/locale/locale.alias

%files locales
%defattr(-,root,root)
%{_prefix}/lib/locale/*
%exclude %{_prefix}/lib/locale/C.utf8/*

%files utils
%defattr(-,root,root)
%{_sbindir}/sln
%{_bindir}/gencat
%{_bindir}/getconf
%{_bindir}/getent
%{_bindir}/iconv
%{_bindir}/iconvconfig
%{_bindir}/ld.so
%{_bindir}/ldd
%{_bindir}/locale
%{_bindir}/localedef
%{_bindir}/locale-gen
%{_bindir}/pldd
%{_bindir}/sprof
%{_bindir}/tzselect
%{_bindir}/mtrace
%{_bindir}/pcprofiledump
%{_bindir}/sotruss
%{_bindir}/xtrace
%if "%{glibc_target_cpu}" == "%{_build_cpu}"
%{_bindir}/memusage
%{_bindir}/memusagestat
%{_bindir}/makedb
%endif
%{glibc_libdir}/audit/sotruss-lib.so
%{slibdir}/libmemusage.so
%{slibdir}/libpcprofile.so

%files -n ldconfig
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/ld.so.conf
%dir %{_sysconfdir}/ld.so.conf.d
%{_sbindir}/ldconfig

%files -n nscd
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/logrotate.d/nscd
%config(noreplace) %{_sysconfdir}/nscd.conf
%{_unitdir}/nscd.service
%{_tmpfilesdir}/nscd.conf
%{_bindir}/nscd
%attr(0755,nscd,nscd) /var/log/nscd

%files -n timezone
%defattr(-,root,root)
%{_bindir}/zdump
%{_bindir}/zic

%else
%files -n cross-%{_target_platform}-%{name}%{?bootstrap_append}%{?bigendian_append}%{?softfloat_append}
%defattr(-,root,root)
%if "%{?stage1}" != "1"
%{glibc_prefix}/etc/rpc
%{glibc_libexecdir}/*
%{glibc_prefix}/bin/*
%{glibc_prefix}/sbin/*
%{glibc_libdir}/*
%{glibc_prefix}/share/*
%{glibc_prefix}/%{_localstatedir}/db/Makefile
%endif
%{glibc_includedir}/*
%endif

%changelog
* Fri Jan 31 2025 Automatic Build System <autodist@openmamba.org> 2.41-1mamba
- automatic version update by autodist

* Thu Dec 05 2024 Silvan Calarco <silvan.calarco@mambasoft.it> 2.40-6mamba
- glibc-utils: require (post) gawk, grep, sed

* Sun Oct 20 2024 Silvan Calarco <silvan.calarco@mambasoft.it> 2.40-5mamba
- format /usr/share/i18n/SUPPORTED as expected to fix locale.conf and locale.gen configuration with Calamares

* Sun Oct 13 2024 Silvan Calarco <silvan.calarco@mambasoft.it> 2.40-4mamba
- move locale.gen configuration from glibc to glibc-utils to fix some  upgrade failures cases

* Fri Oct 11 2024 Silvan Calarco <silvan.calarco@mambasoft.it> 2.40-3mamba
- provide locale-gen and /etc/locale.gen mechanism to generate /usr/lib/locale-archive
- provide C.utf8 as always preinstalled locale
- add glibc-common and integrate glibc-i18n, obsolete locales
- provide preprocessed locales in glibc-locales

* Fri Jul 26 2024 Silvan Calarco <silvan.calarco@mambasoft.it> 2.40-2mamba
- nscd: provide user and group nscd

* Mon Jul 22 2024 Automatic Build System <autodist@openmamba.org> 2.40-1mamba
- automatic version update by autodist

* Wed Feb 07 2024 Automatic Build System <autodist@openmamba.org> 2.39-1mamba
- automatic version update by autodist

* Thu Aug 17 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 2.38-3mamba
- require(pre) libxcrypt to fix badly breaking dnf update

* Thu Aug 17 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 2.38-2mamba
- release bump to override multilib package removal

* Tue Aug 01 2023 Automatic Build System <autodist@mambasoft.it> 2.38-1mamba
- automatic version update by autodist

* Sun Feb 05 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 2.37-2mamba
- fix executable permissions on ld-linux* removed by rpm script

* Sat Feb 04 2023 Automatic Build System <autodist@mambasoft.it> 2.37-1mamba
- automatic version update by autodist

* Tue Aug 02 2022 Automatic Build System <autodist@mambasoft.it> 2.36-1mamba
- automatic version update by autodist

* Thu Jun 16 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 2.35-2mamba
- remove /etc/ld.so.conf/glibc[64].conf files adding /lib[64] before usr-merge to fix e.g. apps based on QtWebEngine

* Sat Feb 05 2022 Automatic Build System <autodist@mambasoft.it> 2.35-1mamba
- automatic version update by autodist

* Wed Sep 29 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 2.34-5mamba
- added pre-2.34 legacy .so symlinks

* Sun Aug 15 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 2.34-4mamba
- triggerpostun glibc < 2.34-4mamba: lua script to finally migrate /lib[64] to /usr/lib[64] and symlink to them

* Mon Aug 09 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 2.34-3mamba
- triggerpostun from glibc 2.33: this time use lua to really fix the lib -> /usr/lib migration

* Sat Aug 07 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 2.34-2mamba
- fixes for migration of ld-linux.so.2 from /lib[64] to /usr/lib[64]

* Fri Aug 06 2021 Automatic Build System <autodist@mambasoft.it> 2.34-1mamba
- automatic version update by autodist

* Fri Feb 05 2021 Automatic Build System <autodist@mambasoft.it> 2.33-1mamba
- automatic version update by autodist

* Thu Aug 06 2020 Automatic Build System <autodist@mambasoft.it> 2.32-1mamba
- automatic version update by autodist

* Tue Mar 03 2020 Automatic Build System <autodist@mambasoft.it> 2.31-1mamba
- automatic version update by autodist

* Thu Dec 26 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 2.30-7mamba
- restore passing buildflags and don't strip libpthread-* and libthread_db-* for debugging
- x86_64: restore glibc-multilib and glibc-multilib-devel subpackages since conflicts with glibc.i586 are resolved by using /usr/lib32

* Tue Dec 10 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 2.30-6mamba
- install tmpfiles.d/nscd.conf

* Thu Dec 05 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 2.30-5mamba
- x86: rebuilt with gcc with cet support to fix 'ld-linux.so.2: corrupt GNU_PROPERTY_TYPE (5) size: 0'

* Sat Nov 23 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 2.30-4mamba
- x86_64: build 32 bit multilib library in unique build

* Fri Nov 22 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 2.30-3mamba
- specfile simplification
- removed profile static target support
- added --enable-cet --enable-lock-elision --enable-stack-protector=strong --enable-stackguard-randomization

* Sat Oct 26 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 2.30-2mamba
- remove workaround to not strip libthread_db.so to fix provides (check later if debugging works)

* Fri Aug 16 2019 Automatic Build System <autodist@mambasoft.it> 2.30-1mamba
- automatic version update by autodist

* Thu Feb 28 2019 Automatic Build System <autodist@mambasoft.it> 2.29-1mamba
- automatic version update by autodist

* Sun Sep 23 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 2.28-3mamba
- glibc: require locales package

* Fri Sep 21 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 2.28-2mamba
- multiarch: move tools from glibc to glibc-utils and require it; ix86: obsolete glibc-multilib 

* Wed Aug 01 2018 Automatic Build System <autodist@mambasoft.it> 2.28-1mamba
- automatic version update by autodist

* Fri Feb 09 2018 Automatic Build System <autodist@mambasoft.it> 2.27-1mamba
- automatic version update by autodist

* Sat Dec 23 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 2.26-3mamba
- added xlocale.h legacy symlink to locale.h
- nscd: switch to systemd

* Sat Sep 30 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 2.26-2mamba
- rebuilt without --enable-obsolete-rpc

* Sat Sep 09 2017 Automatic Build System <autodist@mambasoft.it> 2.26-1mamba
- automatic version update by autodist

* Sun Jul 23 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 2.25-2mamba
- patch to fix unexported function in libresolv breaking runtime and buildtime things

* Fri Jul 21 2017 Automatic Build System <autodist@mambasoft.it> 2.25-1mamba
- automatic version update by autodist

* Fri Aug 05 2016 Automatic Build System <autodist@mambasoft.it> 2.24-1mamba
- automatic version update by autodist

* Fri Feb 19 2016 Automatic Build System <autodist@mambasoft.it> 2.23-1mamba
- automatic version update by autodist

* Mon Aug 17 2015 Automatic Build System <autodist@mambasoft.it> 2.22-1mamba
- automatic version update by autodist

* Sun Apr 12 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 2.21-3mamba
- new cross target: arm-openmamba-linux-gnueabihf

* Thu Mar 26 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 2.21-2mamba
- patch to prevent exhaustion of tls slots (vlc), see https://bugzilla.redhat.com/show_bug.cgi?id=1124987

* Mon Feb 09 2015 Automatic Build System <autodist@mambasoft.it> 2.21-1mamba
- automatic version update by autodist

* Mon Sep 08 2014 Automatic Build System <autodist@mambasoft.it> 2.20-1mamba
- automatic version update by autodist

* Sat Aug 23 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.19-4mamba
- timezone: remove post script to avoid messing /etc/localtime and /etc/timezone
- x86_64: remove nscd and memusagestat to hopefully silent multiling warning about missing 32bit libs

* Wed Jun 11 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.19-3mamba
- fix %pre old %{_includedir}/asm symlink stuff

* Sun Apr 20 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 2.19-2mamba
- rebuilt with enable-obsolete-rpc required by pwdutils

* Sun Feb 09 2014 Automatic Build System <autodist@mambasoft.it> 2.19-1mamba
- automatic version update by autodist

* Sat Aug 17 2013 Automatic Build System <autodist@mambasoft.it> 2.18-1mamba
- automatic version update by autodist

* Tue Jan 15 2013 Automatic Build System <autodist@mambasoft.it> 2.17-1mamba
- update to 2.17

* Mon Oct 01 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.16.0-2mamba
- restore installing rpcnis headers needed by samba
- source edit: install de_AT locale because required by perl-libintl

* Fri Sep 28 2012 Automatic Build System <autodist@mambasoft.it> 2.16.0-1mamba
- automatic version update by autodist

* Thu Jun 14 2012 Automatic Build System <autodist@mambasoft.it> 2.15-1mamba
- automatic version update by autodist

* Mon Oct 10 2011 Automatic Build System <autodist@mambasoft.it> 2.14.1-1mamba
- automatic version update by autodist

* Wed Aug 24 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.14-5mamba
- complete rpc/nis patch by reexporting symbols

* Tue Aug 23 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.14-4mamba
- rebuilt with 2.6.38 kernel headers for x86 and x86_64 targets (for arm still use 2.6.35)
- added a patch to restore rpc/nis headers (http://permalink.gmane.org/gmane.linux.pld.devel.english/7397)

* Sat Aug 13 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.14-3mamba
- added patch to fix resolver crash in __libc_res_query

* Thu Aug 11 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.14-2mamba
- added patch to fix several crashes in dl_lookup (eg. libSDL). See http://sourceware.org/bugzilla/show_bug.cgi?id=12871

* Thu Jul 07 2011 Automatic Build System <autodist@mambasoft.it> 2.14-1mamba
- automatic update by autodist

* Tue Apr 19 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.13-4mamba
- don't build debug package for cross-platform targets to avoid overwriting native glibc-debug package

* Fri Apr 01 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.13-3mamba
- timezone: modify to use zoneinfo from tzdata

* Sat Feb 19 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.13-2mamba
- add patch to fix a prelink segmentation fault in ld.so causing whole system crash

* Sat Feb 12 2011 Automatic Build System <autodist@mambasoft.it> 2.13-1mamba
- update to 2.13

* Tue Dec 14 2010 Automatic Build System <autodist@mambasoft.it> 2.12.2-1mamba
- automatic update to 2.12.2 by autodist

* Mon Dec 13 2010 Davide Madrisan <davide.madrisan@gmail.com> 2.12.1-3mamba
- provides rtld(GNU_HASH) for google-talkplugin and other closed-source packages

* Wed Nov 24 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.12.1-2mamba
- rebuilt with debug package
- don't strip libthread_db.so.1 to allow multithreaded debugging

* Tue Aug 17 2010 Automatic Build System <autodist@mambasoft.it> 2.12.1-1mamba
- update to 2.12.1

* Fri May 28 2010 Automatic Build System <autodist@mambasoft.it> 2.11.2-1mamba
- automatic update to 2.11.2 by autodist

* Sat Mar 13 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.11.1-2mamba
- rebuilt with kernel 2.6.31 headers

* Fri Nov 13 2009 Automatic Build System <autodist@mambasoft.it> 2.11-1mamba
- update to 2.11

* Tue Nov 03 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.10.1-5mamba
- added es_ES* locale support

* Thu Sep 24 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.10.1-4mamba
- revert back previous patch because kde and maybe other software need to be rebuilt without internal str* functions

* Fri Sep 11 2009 Automatic Build System <autodist@mambasoft.it> 2.10.1-3mamba
- automatic rebuild by autodist
- readded BSD-like strlcpy strlcat patch

* Wed Aug 12 2009 Automatic Build System <autodist@mambasoft.it> 2.10.1-2mamba
- automatic rebuild by autodist

* Thu May 28 2009 Automatic Build System <autodist@mambasoft.it> 2.10.1-1mamba
- update to 2.10.1

* Wed Apr 29 2009 Automatic Build System <autodist@mambasoft.it> 2.9-3mamba
- build with ports and libidn

* Wed Apr 29 2009 Automatic Build System <autodist@mambasoft.it> 2.9-2mamba
- automatic rebuild by autodist

* Wed Apr 15 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.9-1mamba
- update to 2.9

* Wed Jan 28 2009 Davide Madrisan <davide.madrisan@gmail.com> 2.7-6mamba
- patch: x86-fnstsw.patch (fixes "suffix or operands invalid for `fnstsw'" in ftestexcept.c)

* Tue Sep 16 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.7-5mamba
- rebuilt with gcc 4.3.2 and 2.6.26.5 kernel headers

* Tue Feb 05 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.7-4mamba
- patch: only-lookup-ipv6-if-it-makes-sense (should fix ipv6 dns requests resolved to 1.0.0.0)
- patch: arm_lowlevellock fixed and renamed to lowlevellock

* Tue Dec 18 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.7-3mamba
- post script: update /etc/localtime file

* Fri Dec 14 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.7-2mamba
- move i18ndata script to posttrans to avoid missing prereqs errors
- added stricter version requirements for glibc-profile and others
- fixed a couple of errors in i18ndata postrans script

* Wed Nov 28 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.7-1mamba
- update to 2.7
- added html documentation
- added cross-<platform>-glibc-stage2 provide to cross-<platform>-glibc
- added support for a limited set of default locales
- i18ndata: update locale-archive according to current LANG setting

* Fri Mar 30 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.5-4mamba
- rebuilt with sanitized headers from clfs
- added patch that adds strlcpy and strlcat functions

* Sat Mar 24 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.5-3qilnx
- rebuild for the openmamba platform
- cross packages obsoletion of both stage1 and stage2 transient packages

* Fri Mar 09 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.5-2qilnx
- kernel headers update to 2.6.20
- sln moved from tools to main package for LSB compliance
- ld.so.conf: add support for includes directory ld.so.conf.d

* Fri Nov 24 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.5-1qilnx
- new version build

* Sat Jun 24 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4-2qilnx
- rebuilt with cleaned headers from kernel 2.6.17

* Fri Jun 09 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4-1qilnx
- new version build
- added arm support
- added stage1 (only headers) and stage2 (only c cross compiler) build support

* Wed Jan 25 2006 Davide Madrisan <davide.madrisan@qilinux.it> 2.3.6-3qilnx
- patched sys/kd.h header to make linux/agpgart.h usable from userspace

* Fri Nov 04 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.6-2qilnx
- added /usr/include/sound headers from kernel sources
- removed the now obsolete linuxthreads stuff

* Fri Nov 04 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.6-1qilnx
- update to version 2.3.6 by autospec

* Wed Sep 07 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.5-5qilnx
- add qilinux headers installation (currently for sisfb.h)
- add cross-platform (cross-glibc) build target

* Thu Aug 25 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.5-4qilnx
- add specfile code for cross-platform builds
- add maintained sanitized kernel headers
- /sbin/sln moved to glibc-utils package

* Mon Jun 06 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.3.5-3qilnx
- run make check
- install man pages for linuxthread (devel package)

* Mon Jun 06 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.3.5-2qilnx
- updated kernel headers to release 2.6.11
- added package 'glibc-profile' (support for gprof profiling)
- enabled selinux support

* Thu Apr 07 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.3.5-1qilnx
- update to version 2.3.5 by autospec
- updated kernel headers to release 2.4.30

* Fri Feb 11 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.3.4-3qilnx
- removed pre scriptlet

* Wed Feb 02 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.3.4-2qilnx
- moved `ld.so.conf' and `ld.so.cache' to package ldconfig
- removed configure option `--libexecdir=${_bindir}'

* Fri Jan 28 2005 Davide Madrisan <davide.madrisan@qilinux.it> 2.3.4-1qilnx
- update to 2.3.4

* Mon Jan 12 2004 Davide Madrisan <davide.madrisan@qilinux.it> 2.3.2-9qilnx
- fixed specfile summary

* Mon Dec 15 2003 Davide Madrisan <davide.madrisan@qilinux.it> 2.3.2-8qilnx
- disabled nscd hosts caching, specfile updates
- kernel headers updated to version 2.4.22

* Tue Sep 30 2003 Silvan Calarco <silvan.calarco@mambasoft.it> 2.3.2-7qilnx
- added nscd package and automatic service configuration

* Mon Jun 16 2003 Silvan Calarco <silvan.calarco@qinet.it> 2.3.2-6qilnx
- rebuilt against gcc 3.2.3

* Mon May 05 2003 Silvan Calarco <silvan.calarco@qinet.it> 2.3.2-5qilnx
- removed /etc/localtime link (will be in setup package)

* Thu Apr 24 2003 Silvan Calarco <silvan.calarco@qinet.it> 2.3.2-4qilnx
- added linux kernel includes: /usr/include/linux, /usr/include/asm
- addded _libdir files in devel package

* Wed Apr 16 2003 Silvan Calarco <silvan.calarco@qinet.it> 2.3.2-3qilnx
- removed _libdir and _bindir * references not to include util package files

* Wed Apr 16 2003 Silvan Calarco <silvan.calarco@qinet.it> 2.3.2-2qilnx
- fixed find_requires and find_provides scripts: ignore GLIBC_PRIVATE references
- added util package, so glibc doesn't need perl as a dependancy

* Tue Apr 08 2003 Silvan Calarco <silvan.calarco@qinet.it> 2.3.2-1qilnx
- first build for 2.3.2
